NumpyDataProduct
================

.. currentmodule:: oda_api.data_products

.. autoclass:: NumpyDataProduct
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NumpyDataProduct.decode
      ~NumpyDataProduct.encode
      ~NumpyDataProduct.from_fits_file
      ~NumpyDataProduct.get_data_unit
      ~NumpyDataProduct.get_data_unit_by_name
      ~NumpyDataProduct.show
      ~NumpyDataProduct.show_meta
      ~NumpyDataProduct.to_fits_hdu_list
      ~NumpyDataProduct.write_fits_file

   .. rubric:: Methods Documentation

   .. automethod:: decode
   .. automethod:: encode
   .. automethod:: from_fits_file
   .. automethod:: get_data_unit
   .. automethod:: get_data_unit_by_name
   .. automethod:: show
   .. automethod:: show_meta
   .. automethod:: to_fits_hdu_list
   .. automethod:: write_fits_file
